@@ -111,16 +111,16 @@ sub try_include_file {
 	return system("$Config{cc} $out_filename") == 0 ? $lib_name : undef;
 }
 
+# Now patch tcc.h for the proper ucontext location. Put the detection code
+# inside the patch snippet so that the tests only run once.
 if (-f 'src/tcc.h') {
-	# Now patch tcc.h for the proper ucontext location. Put the detection
-	# code inside the patch snippet so that the tests only run once.
 	My::Build::apply_patches('src/tcc.h',
 		qr/#\s*include.*ucontext/ => sub {
 			my ($in_fh, $out_fh, $line) = @_;
 	
 			# Find the proper include location for ucontext.h
-			my $ucontext_include = try_include_file('sys/ucontext.h')
-				|| try_include_file('ucontext.h')
+			my $ucontext_include = try_include_file('ucontext.h')
+				|| try_include_file('sys/ucontext.h')
 				|| die "Unable to locate ucontext!";
 			# Clean up after compilation tests.
 			unlink 'a.out';
@@ -129,68 +129,6 @@ if (-f 'src/tcc.h') {
 			return 1;
 		},
 	);
-
-#### IGNORING FOR NOW. I think this needs to be applied, but I don't
-#### have any test reports from Cygwin to tell me what to do.
-#	# Apply patch to keep Cygwin happy
-#	My::Build::apply_patches('src/tccrun.c',
-#		qr/uc->uc_mcontext\.mc_r[bi]p;/ => sub {
-#			my ($in_fh, $out_fh, $line) = @_;
-#			
-#			# Keep original code
-#			print $out_fh $line;
-#			
-#			# Check if these changes have already been applied. The
-#			# next line is either "#else" (which means not applied)
-#			# or "#elif ..." (which means applied)
-#			my $next_line = <$in_fh>;
-#			if ($next_line =~ /elif/) {
-#				# Nothing to do; return indicating we've handled the
-#				# line.
-#				print $out_fh $next_line;
-#				return 1;
-#			}
-#			
-#			# Apply a few preprocessor if/else lines, too
-#			if ($line =~ /paddr/) {
-#				print $out_fh <<'PADDR_PATCH';
-##elif defined(__CYGWIN__)
-#        *paddr = uc->uc_mcontext.rip;
-#PADDR_PATCH
-#			}
-#			elsif ($line =~ /fp/) {
-#				print $out_fh <<'FP_PATCH';
-##elif defined(__CYGWIN__)
-#        fp = uc->uc_mcontext.rbp;
-#FP_PATCH
-#			}
-#			else {
-#				die "Unexpected patch line:\n$line";
-#			}
-#			print $out_fh $next_line;
-#			
-#			# patcher does *not* need to include this line, we've
-#			# already done that.
-#			return 1;
-#		},
-#	);
-	
-	# Turn off stack protection
-	my $stack_protector_removed;
-	My::Build::apply_patches('src/Makefile',
-		qr/fno-stack-protector/ => sub {
-			$stack_protector_removed = 1;
-			return;
-		},
-	);
-	My::Build::apply_patches('src/Makefile',
-		qr/else # not GCC/ => sub {
-			my ($in_fh, $out_fh, $line) = @_;
-			print $out_fh "CFLAGS+=-fno-stack-protector\n"
-				unless $stack_protector_removed;
-			return;
-		},
-	);
 }
 
 1;
